@@ -4,10 +4,12 @@
 from .acme import ACMEAccount
 from .admin import Admin
 from .client import Client
+from .domain import Domain
+from .report import Report
 from ._helpers import Pending
 from .organization import Organization
 from .person import Person
 from .smime import SMIME
 from .ssl import SSL
 
-__all__ = ["ACMEAccount", "Admin", "Client", "Organization", "Pending", "Person", "SMIME", "SSL"]
+__all__ = ["ACMEAccount", "Admin", "Client", "Domain", "Organization", "Pending", "Person", "Report", "SMIME", "SSL"]
