@@ -13,7 +13,7 @@ from ._helpers import traffic_log
 LOGGER = logging.getLogger(__name__)
 
 
-class Client(object):
+class Client:  # pylint: disable=too-many-instance-attributes
     """Serve as a Base class for calls to the Sectigo Cert Manager APIs."""
 
     DOWNLOAD_TYPES = [
@@ -129,6 +129,21 @@ class Client(object):
                     del self.__headers[head]
                     del self.__session.headers[head]
 
+    @traffic_log(traffic_logger=LOGGER)
+    def head(self, url, headers=None, params=None):
+        """Submit a HEAD request to the provided URL.
+
+        :param str url: A URL to query
+        :param dict headers: A dictionary with any extra headers to add to the request
+        :param dict params: A dictionary with any parameters to add to the request URL
+        :return obj: A requests.Response object received as a response
+        """
+        result = self.__session.head(url, headers=headers, params=params)
+        # Raise an exception if the return code is in an error range
+        result.raise_for_status()
+
+        return result
+
     @traffic_log(traffic_logger=LOGGER)
     def get(self, url, headers=None, params=None):
         """Submit a GET request to the provided URL.
@@ -175,14 +190,15 @@ class Client(object):
         return result
 
     @traffic_log(traffic_logger=LOGGER)
-    def delete(self, url, headers=None):
+    def delete(self, url, headers=None, data=None):
         """Submit a DELETE request to the provided URL.
 
         :param str url: A URL to query
         :param dict headers: A dictionary with any extra headers to add to the request
+        :param dict data: A dictionary with the data to use for the body of the DELETE
         :return obj: A requests.Response object received as a response
         """
-        result = self.__session.delete(url, headers=headers)
+        result = self.__session.delete(url, json=data, headers=headers)
         # Raise an exception if the return code is in an error range
         result.raise_for_status()
 
